==> orchestra-base-tomcat-4.7.0.zip: orchestra-base-tomcat-4.7.0/package/resources/db-schemas/history/org.hibernate.dialect.DerbyDialect-drop.sql <==
alter table MON_DEF_ACTIVITY drop constraint FKB2087C9CF1C5FAB0;
alter table MON_DEF_ACTIVITY drop constraint FKB2087C9C82112BDD;
alter table MON_DEF_ACTIVITY drop constraint FKB2087C9C614874B5;
alter table MON_DEF_ACTIVITY drop constraint FKB2087C9CDE3B31AF;
alter table MON_DEF_ACTIVITY drop constraint FKB2087C9CD4D0807A;
alter table MON_DEF_ACTIVITY drop constraint SCOPE_DEF_FAULT_HANDLERS_FK;
alter table MON_DEF_COPY drop constraint COPY_LST_FK;
alter table MON_DEF_CORR drop constraint REC_CR_DEF_LST_FK;
alter table MON_DEF_CORR drop constraint IVK_CR_DEF_LST_FK;
alter table MON_DEF_CORR drop constraint RP_CR_DEF_LST_FK;
alter table MON_DEF_CORR drop constraint ON_EVT_CORR_FK;
alter table MON_DEF_CORR drop constraint ON_MSG_CORR_FK;
alter table MON_DEF_ELSEIF drop constraint IF_ELSEIF_LST_FK;
alter table MON_DEF_ELSEIF drop constraint FK802DBCE366DBBFD7;
alter table MON_DEF_FROM_PART drop constraint REC_FR_PT_LST_FK;
alter table MON_DEF_FROM_PART drop constraint IVK_FR_PT_LST_FK;
alter table MON_DEF_FROM_PART drop constraint ON_MSG_FRM_PRT_FK;
alter table MON_DEF_FROM_PART drop constraint ON_EVT_FRM_PRT_FK;
alter table MON_DEF_FROM_TO drop constraint FROM_LST_FK;
alter table MON_DEF_FROM_TO drop constraint TO_LST_FK;
alter table MON_DEF_LINK drop constraint FLOW_LINKS_FK;
alter table MON_DEF_LINK_SRC drop constraint SRC_LST_FK;
alter table MON_DEF_LINK_TGT drop constraint TRGT_LST_FK;
alter table MON_DEF_MSG_EXCHG drop constraint SCOPE_DEF_M_E_FK;
alter table MON_DEF_ON_ALRM drop constraint PK_DF_ON_AL_FK;
alter table MON_DEF_ON_ALRM drop constraint FK9A9936D9735C61C7;
alter table MON_DEF_ON_ALRM drop constraint SCOPE_DEF_ALARMS_FK;
alter table MON_DEF_ON_EVT drop constraint FK915FD83099EA93C4;
alter table MON_DEF_ON_EVT drop constraint SCOPE_DEF_EVTS_FK;
alter table MON_DEF_ON_MSG drop constraint PK_DF_ON_MSG_FK;
alter table MON_DEF_ON_MSG drop constraint FK915FF5CEA6853462;
alter table MON_DEF_PART_LNK drop constraint SCOPE_DEF_PL_FK;
alter table MON_DEF_PROC_STATE drop constraint PROCESS_STATE_FK;
alter table MON_DEF_TO_PART drop constraint RP_TO_PT_LST_FK;
alter table MON_DEF_TO_PART drop constraint IVK_TO_PT_LST_FK;
alter table MON_DEF_VAR drop constraint SCOPE_DEF_VAR_FK;
alter table MON_DEF_VAR_CS drop constraint SCOPE_DEF_CS_FK;
alter table MON_DEF_VAR_CS_properties drop constraint CORR_ST_DEF_FK;
alter table MON_RUNT_ACTIVITY drop constraint ACT_INST_PARENT_FK;
alter table MON_RUNT_ACTIVITY drop constraint ACT_INST_CH_FK;
alter table MON_RUNT_ACTIVITY drop constraint ACT_INST_TH_FK;
alter table MON_RUNT_ACTIVITY drop constraint ACT_INST_FH_FK;
alter table MON_RUNT_ACTIVITY drop constraint ACT_INST_EXCEPTION_FK;
alter table MON_RUNT_ACTIVITY drop constraint ACT_INST_WAIT_FK;
alter table MON_RUNT_ACTIVITY drop constraint ACT_INST_CHILD_FK;
alter table MON_RUNT_ACTIVITY drop constraint SCOPE_INST_EVT_FK;
alter table MON_RUNT_CS_INIT drop constraint SCOPE_INST_CS_FK;
alter table MON_RUNT_CS_PROP drop constraint CS_INST_PROP_FK;
alter table MON_RUNT_INST_STATE drop constraint PROCESS_INST_STATE_FK;
alter table MON_RUNT_PLNK_UPDATE drop constraint SCOPE_INST_PLNK_FK;
alter table MON_RUNT_SCOPE_STATE drop constraint SCOPE_INST_STATE_FK;
alter table MON_RUNT_TR_COND_UPD_ drop constraint FLOW_INST_TR_COND_FK;
alter table MON_RUNT_VAR_UPDATE drop constraint SCOPE_INST_VAR_FK;
alter table MON_RUNT_WAITING drop constraint PICK_WAIT_FK;
drop table MON_DEF_ACTIVITY;
drop table MON_DEF_COPY;
drop table MON_DEF_CORR;
drop table MON_DEF_ELSEIF;
drop table MON_DEF_FROM_PART;
drop table MON_DEF_FROM_TO;
drop table MON_DEF_LINK;
drop table MON_DEF_LINK_SRC;
drop table MON_DEF_LINK_TGT;
drop table MON_DEF_MSG_EXCHG;
drop table MON_DEF_ON_ALRM;
drop table MON_DEF_ON_EVT;
drop table MON_DEF_ON_MSG;
drop table MON_DEF_PART_LNK;
drop table MON_DEF_PROC_STATE;
drop table MON_DEF_TO_PART;
drop table MON_DEF_VAR;
drop table MON_DEF_VAR_CS;
drop table MON_DEF_VAR_CS_properties;
drop table MON_RUNT_ACTIVITY;
drop table MON_RUNT_BPEL_FAULT_;
drop table MON_RUNT_CS_INIT;
drop table MON_RUNT_CS_PROP;
drop table MON_RUNT_INST_STATE;
drop table MON_RUNT_PLNK_UPDATE;
drop table MON_RUNT_RECORD;
drop table MON_RUNT_SCOPE_STATE;
drop table MON_RUNT_TR_COND_UPD_;
drop table MON_RUNT_VAR_UPDATE;
drop table MON_RUNT_WAITING;
drop table BPEL_HISTORY_SEQS;

==> orchestra-base-tomcat-4.9.0.zip: orchestra-base-tomcat-4.9.0/package/resources/db-schemas/history/org.hibernate.dialect.DerbyDialect-drop.sql <==
alter table MON_DEF_ACTIVITY drop constraint FKB2087C9CF1C5FAB0;
alter table MON_DEF_ACTIVITY drop constraint FKB2087C9C82112BDD;
alter table MON_DEF_ACTIVITY drop constraint FKB2087C9C614874B5;
alter table MON_DEF_ACTIVITY drop constraint FKB2087C9CDE3B31AF;
alter table MON_DEF_ACTIVITY drop constraint FKB2087C9CD4D0807A;
alter table MON_DEF_ACTIVITY drop constraint SCOPE_DEF_FAULT_HANDLERS_FK;
alter table MON_DEF_COPY drop constraint COPY_LST_FK;
alter table MON_DEF_CORR drop constraint REC_CR_DEF_LST_FK;
alter table MON_DEF_CORR drop constraint IVK_CR_DEF_LST_FK;
alter table MON_DEF_CORR drop constraint RP_CR_DEF_LST_FK;
alter table MON_DEF_CORR drop constraint ON_EVT_CORR_FK;
alter table MON_DEF_CORR drop constraint ON_MSG_CORR_FK;
alter table MON_DEF_ELSEIF drop constraint IF_ELSEIF_LST_FK;
alter table MON_DEF_ELSEIF drop constraint FK802DBCE366DBBFD7;
alter table MON_DEF_EXT drop constraint PROCESS_EXT_FK;
alter table MON_DEF_FROM_PART drop constraint REC_FR_PT_LST_FK;
alter table MON_DEF_FROM_PART drop constraint IVK_FR_PT_LST_FK;
alter table MON_DEF_FROM_PART drop constraint ON_MSG_FRM_PRT_FK;
alter table MON_DEF_FROM_PART drop constraint ON_EVT_FRM_PRT_FK;
alter table MON_DEF_FROM_TO drop constraint FROM_LST_FK;
alter table MON_DEF_FROM_TO drop constraint TO_LST_FK;
alter table MON_DEF_LINK drop constraint FLOW_LINKS_FK;
alter table MON_DEF_LINK_SRC drop constraint SRC_LST_FK;
alter table MON_DEF_LINK_TGT drop constraint TRGT_LST_FK;
alter table MON_DEF_MSG_EXCHG drop constraint SCOPE_DEF_M_E_FK;
alter table MON_DEF_ON_ALRM drop constraint PK_DF_ON_AL_FK;
alter table MON_DEF_ON_ALRM drop constraint FK9A9936D9735C61C7;
alter table MON_DEF_ON_ALRM drop constraint SCOPE_DEF_ALARMS_FK;
alter table MON_DEF_ON_EVT drop constraint FK915FD83099EA93C4;
alter table MON_DEF_ON_EVT drop constraint SCOPE_DEF_EVTS_FK;
alter table MON_DEF_ON_MSG drop constraint PK_DF_ON_MSG_FK;
alter table MON_DEF_ON_MSG drop constraint FK915FF5CEA6853462;
alter table MON_DEF_PART_LNK drop constraint SCOPE_DEF_PL_FK;
alter table MON_DEF_PROC_STATE drop constraint PROCESS_STATE_FK;
alter table MON_DEF_RESOURCES drop constraint FKCA16618F2951188;
alter table MON_DEF_TO_PART drop constraint RP_TO_PT_LST_FK;
alter table MON_DEF_TO_PART drop constraint IVK_TO_PT_LST_FK;
alter table MON_DEF_VAR drop constraint SCOPE_DEF_VAR_FK;
alter table MON_DEF_VAR_CS drop constraint SCOPE_DEF_CS_FK;
alter table MON_DEF_VAR_CS_properties drop constraint CORR_ST_DEF_FK;
alter table MON_RUNT_ACTIVITY drop constraint ACT_INST_PARENT_FK;
alter table MON_RUNT_ACTIVITY drop constraint ACT_INST_CH_FK;
alter table MON_RUNT_ACTIVITY drop constraint ACT_INST_TH_FK;
alter table MON_RUNT_ACTIVITY drop constraint ACT_INST_FH_FK;
alter table MON_RUNT_ACTIVITY drop constraint ACT_INST_EXCEPTION_FK;
alter table MON_RUNT_ACTIVITY drop constraint ACT_INST_WAIT_FK;
alter table MON_RUNT_ACTIVITY drop constraint ACT_INST_CHILD_FK;
alter table MON_RUNT_ACTIVITY drop constraint SCOPE_INST_EVT_FK;
alter table MON_RUNT_CS_INIT drop constraint SCOPE_INST_CS_FK;
alter table MON_RUNT_CS_PROP drop constraint CS_INST_PROP_FK;
alter table MON_RUNT_INST_STATE drop constraint PROCESS_INST_STATE_FK;
alter table MON_RUNT_PLNK_UPDATE drop constraint SCOPE_INST_PLNK_FK;
alter table MON_RUNT_SCOPE_STATE drop constraint SCOPE_INST_STATE_FK;
alter table MON_RUNT_TR_COND_UPD_ drop constraint FLOW_INST_TR_COND_FK;
alter table MON_RUNT_VAR_UPDATE drop constraint SCOPE_INST_VAR_FK;
alter table MON_RUNT_WAITING drop constraint PICK_WAIT_FK;
drop table MON_DEF_ACTIVITY;
drop table MON_DEF_COPY;
drop table MON_DEF_CORR;
drop table MON_DEF_ELSEIF;
drop table MON_DEF_EXT;
drop table MON_DEF_FROM_PART;
drop table MON_DEF_FROM_TO;
drop table MON_DEF_LINK;
drop table MON_DEF_LINK_SRC;
drop table MON_DEF_LINK_TGT;
drop table MON_DEF_MSG_EXCHG;
drop table MON_DEF_ON_ALRM;
drop table MON_DEF_ON_EVT;
drop table MON_DEF_ON_MSG;
drop table MON_DEF_PART_LNK;
drop table MON_DEF_PROC_STATE;
drop table MON_DEF_RESOURCES;
drop table MON_DEF_TO_PART;
drop table MON_DEF_VAR;
drop table MON_DEF_VAR_CS;
drop table MON_DEF_VAR_CS_properties;
drop table MON_RUNT_ACTIVITY;
drop table MON_RUNT_BPEL_FAULT_;
drop table MON_RUNT_CS_INIT;
drop table MON_RUNT_CS_PROP;
drop table MON_RUNT_INST_STATE;
drop table MON_RUNT_PLNK_UPDATE;
drop table MON_RUNT_RECORD;
drop table MON_RUNT_SCOPE_STATE;
drop table MON_RUNT_TR_COND_UPD_;
drop table MON_RUNT_VAR_UPDATE;
drop table MON_RUNT_WAITING;
drop table BPEL_HISTORY_SEQS;
